@@ -5,6 +5,8 @@ import pygame.display
 pygame.init()
 pygame.display.init()
 displaya = None
+display_size = [0,0]
+eventsl = None
 system("clear")
 print("Pygame Extra 1.6.X is installed correctly!")
 scriptpath = str(__file__).replace("__init__.py",'')
@@ -12,6 +14,8 @@ scriptpath = str(__file__).replace("__init__.py",'')
 slider_image = None
 #RESOURCE LOADING# /\
 #Emergency call functions# \/
+def PE___entry___PE():
+    print('test')
 def error(textS):
   pygame.quit()
   print(textS)
@@ -55,6 +59,9 @@ class display:
     displaya = dis
   
   def make(size, caption):
+    global display_size
+    display_size[0] = size[0]
+    display_size[1] = size[1]
     dis = pygame.display.set_mode(size)
     pygame.display.set_caption(caption)
     display.set(dis)
@@ -96,6 +103,8 @@ class draw:
     if Settings.update_auto:
       display.update()
 
+  def ellipse(color, rect):
+    pygame.draw.ellipse(displaya,color,rect)
 class fill:
   def full(color):
     displaya.fill(color)
@@ -156,7 +165,7 @@ class time:
     pygame.time.delay(time)
   def tick(tickrate=120):
     pygame.time.Clock().tick(tickrate)
-def quit():
+def Pquit():
   pygame.quit()
   
 class button:
@@ -501,14 +510,35 @@ class slider:
         pe_values.mouse.in_use = False
     return current
 class event:
-
+  c = None
+  def get():
+    tmp = pygame.event.get()
+    if tmp != None:
+      return tmp
   def quitcheck():
     tmp = False
-    for event in pygame.event.get():
-      if event.type == pygame.QUIT:
-        tmp = True
+    if event.c.type == pygame.QUIT:
+      tmp = True
     return tmp
-
+  def quitcheckauto():
+    if event.quitcheck():
+      pygame.quit()
+      quit()
+  def keylog():
+    if event.c.type == pygame.KEYDOWN or event.c.type == pygame.KEYUP:
+      return event.c.key
+  def key_UP(var):
+    if event.c.type == pygame.KEYUP:
+      if event.c.key == var:
+        return True
+      else:
+        return False
+  def key_DOWN(var):
+    if event.c.type == pygame.KEYDOWN:
+      if event.c.key == var:
+        return True
+      else:
+        return False
 class math:
   def center(rect):
     return ( (rect[0]+(rect[2]/2)), (rect[1]+(rect[3]/2)) )
@@ -570,3 +600,72 @@ class sprite:
         self.new = sprite_r
         return self.new
     return Sprite.setup(Sprite)
+def rect(a,b,c,d):
+  return pygame.Rect(a,b,c,d)
+  #
+class E_intro:
+  def intro(anim,back,t):
+    global display_size
+    if display_size[0] >= 300 and display_size[1] >= 150:
+      fx = (display_size[0] / 2) - 150
+      fy = (display_size[1] / 2) - 50
+      #INTRO \/
+      fill.full(back)
+      if anim != 0:
+        time.sleep(anim)
+      # P \/
+      draw.rect(t,(0+fx,0+fy,25,125),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(0+fx,0+fy,75,25),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(50+fx,0+fy,25,75),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(0+fx,50+fy,75,25),0)
+      # P /\
+      fx += 100             
+      # G \/
+      draw.rect(t,(0+fx,0+fy,75,25),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(back,(0+fx,50+fy,75,25),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(0+fx,0+fy,25,125),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(0+fx,100+fy,75,25),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(50+fx,50+fy,25,75),0)
+      # G /\
+      fx += 100
+      # E \/
+      draw.rect(t,(0+fx,0+fy,75,25),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(0+fx,50+fy,75,25),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(0+fx,0+fy,25,125),0)
+      if anim != 0:
+        time.sleep(anim)
+      draw.rect(t,(0+fx,100+fy,75,25),0)
+      # E /\
+      #INTRO /\
+
+    else:
+      print('======================================')
+      print('resolution too small to display intro!')
+      print('Try again with at least (300,150)')
+      print('=================================')
+  def run(tA=100,tB=100,tC=1000):
+    E_intro.intro(tA,color.white,color.red) # Plays first intro
+    time.sleep(tB)
+    Settings.update_auto = False # Disables auto update
+    E_intro.intro(0,color.black,(0,100,255)) # Plays second intro
+    display.update() # updates
+    time.sleep(tC)
+    Settings.update_auto = True # Enables auto update
